==> 2.4.zip: piwigo/language/lv_LV/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['Upgrade'] = "Uzlabošana";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "Šī lapa piedāvā uzlabot Jūsu Piwigo veco datu bāzi uz jaunāko versiju. Uzlabošanas asistents domā, ka Jūs patlaban lietojat <strong>release %s</strong> ( vai ekvivalentu).";
$lang['Upgrade from version %s to %s'] = "Uzlabojums no  %s versijas uz %s";
$lang['Statistics'] = "Statistika";
$lang['total upgrade time'] = "kopējais uzlabošanas procesa laiks";
$lang['total SQL time'] = "kopējais SQL laiks";
$lang['SQL queries'] = "SQL rindas";
$lang['Upgrade informations'] = "Informācija par uzlabojumu";
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Veiciet profilakses pārbaudi [Administrēšana>Rīki>Profilakse] , ja ir gadījusies kāda kļūme.";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "Piesardzības nolūkos tiek atslēgti sekojoši spraudņi. Pirms tos atkal pieslēgt, pārbaudiet vai nav pieejami to uzlabojumi:";
$lang['Only administrator can run upgrade: please sign in below.'] = "Uzlabojumu var veikt tikai administrators: lūdzu veiciet pierakstīšanos zemāk.";
$lang['You do not have access rights to run upgrade'] = "Jums nav pieejas tiesību, lai veiktu uzlabojumu";
$lang['All sub-albums of private albums become private'] = 'Visi privātā albūma apakšalbūmi kļūst privāti';
$lang['User permissions and group permissions have been erased'] = "Lietotāju un grupu piekļuves tiesības ir izdzēstas";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "No iepriekšējās konfigurācijas ir saglabāti tikai sīkbilžu prefiksi un webmāstera e-pasta adreses";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'Iekš <i>%s</i>, pirms <b>?></b>,ievietot:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Piesardzības pasākumu dēļ, sekojošas tēmas ir deaktivētas. Pirms atkal tās aktivēt, jums jāpārbauda, vai nav pieejami šo tēmu jauninājumi:';
?>

==> 14.5.0.zip: piwigo/language/lv_LV/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+



$lang['Upgrade'] = "Uzlabošana";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "Šī lapa piedāvā uzlabot Jūsu Piwigo veco datu bāzi uz jaunāko versiju. Uzlabošanas asistents domā, ka Jūs patlaban lietojat <strong>release %s</strong> ( vai ekvivalentu).";
$lang['Upgrade from version %s to %s'] = "Uzlabojums no  %s versijas uz %s";
$lang['Statistics'] = "Statistika";
$lang['total upgrade time'] = "kopējais uzlabošanas procesa laiks";
$lang['total SQL time'] = "kopējais SQL laiks";
$lang['SQL queries'] = "SQL rindas";
$lang['Upgrade informations'] = "Informācija par uzlabojumu";
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Veiciet profilakses pārbaudi [Administrēšana>Rīki>Profilakse] , ja ir gadījusies kāda kļūme.";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "Piesardzības nolūkos tiek atslēgti sekojoši spraudņi. Pirms tos atkal pieslēgt, pārbaudiet vai nav pieejami to uzlabojumi:";
$lang['Only administrator can run upgrade: please sign in below.'] = "Uzlabojumu var veikt tikai administrators: lūdzu veiciet pierakstīšanos zemāk.";
$lang['You do not have access rights to run upgrade'] = "Jums nav pieejas tiesību, lai veiktu uzlabojumu";
$lang['All sub-albums of private albums become private'] = 'Visi privātā albūma apakšalbūmi kļūst privāti';
$lang['User permissions and group permissions have been erased'] = "Lietotāju un grupu piekļuves tiesības ir izdzēstas";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "No iepriekšējās konfigurācijas ir saglabāti tikai sīkbilžu prefiksi un webmāstera e-pasta adreses";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'Iekš <i>%s</i>, pirms <b>?></b>,ievietot:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Piesardzības pasākumu dēļ, sekojošas tēmas ir deaktivētas. Pirms atkal tās aktivēt, jums jāpārbauda, vai nav pieejami šo tēmu jauninājumi:';
$lang['Discover what\'s new in Piwigo %s'] = 'Uzzini, kas jauns Piwigo %s';
